==> gnucash_5.1.orig.tar.xz: gnucash-5.1/doc/tip_of_the_day.list.c <==
/* Sort order: Imagine a first time user. When is your tip useful? */

 N_( "The GnuCash online manual has lots of helpful information. \
You can access the manual under the Help menu.")

/* Translators: You can replace the link, if a translated page exists. */
 N_( "Mailing lists are the preferred form of communication in the \
GnuCash community. For announcements of new releases, user groups etc. \
see the table at https://wiki.gnucash.org/wiki/Mailing_Lists")

 N_( "The GnuCash developers are easy to contact. As well \
as several mailing lists, you can chat to them live on IRC! \
Join them on #gnucash at irc.gnome.org")

 N_( "You can easily import your existing financial data from Quicken, \
MS Money or other programs that export QIF files or OFX files. In the \
File menu, click on the sub-menu Import and click on QIF or OFX file, \
respectively. Then, follow the instructions provided.")

 N_( "If you want to know in which directories your recent GnuCash files \
are stored, hover over one of the entries in the history menu\n(File[->\
Most Recently Used-List]).\nThe full path is displayed in the status bar.")

 N_( "If you are familiar with other financial programs such as Quicken, \
note that GnuCash uses accounts instead of categories to track \
income and expenses. For more information on income and expense \
accounts, please see the GnuCash online manual.")

 N_( "It is possible to change which columns display in the Chart of \
Accounts. Just locate the triangle at the far right of the column \
headings, and click it to see the different columns available.")

 N_( "Click the right mouse button (control-click in Mac OS X) in the \
Accounts tab of the main window to bring up the \
account menu options. Within each register, clicking the right \
mouse button brings up the transaction menu options.")

 N_( "Create new accounts by clicking the New button in the main window \
tool bar. This will bring up a dialog box where you can enter \
account details. For more information on choosing an account type \
or setting up a chart of accounts, please see the GnuCash online \
manual.")

N_( "Every transaction has a \"Notes\" field where you can put useful \
information.\n\n\
To make it visible\n\
select \"View\" in the menu bar and check \"Double Line\" or\n\
check \"Double Line Mode\" in Preferences:Register Defaults.")

 N_( "To enter multiple-split transactions such as a paycheck with \
multiple deductions, click the Split button in the tool bar. \
Alternatively, in the View menu, you can choose the register \
style Auto-Split Ledger or Transaction Journal.")

 N_( "As you enter amounts in the register, you can use the GnuCash \
calculator to add, subtract, multiply and divide. Simply type \
the first value, then select '+', '-','*', or '/'. Type the \
second value and press Enter to record the calculated amount.")

 N_( "Quick-fill makes it easy to enter common transactions. When you \
type the first letter(s) of a common transaction description, \
then press the Tab key, GnuCash will automatically complete \
the remainder of the transaction as it was last entered.")

 N_( "Type the first letter(s) of an existing account name in the \
Transfer register column, and GnuCash will complete the name from \
your list of accounts. For subaccounts, type the first letter(s) \
of the parent account, followed by ':' and the first letter(s) of \
the subaccount (e.g. A:C for Assets:Cash).")

 N_( "Want to see all your subaccount transactions in one register? \
From the Accounts tab in the main window, highlight the parent account \
and select Edit->Open Subaccounts from the menu.")

 N_( "When entering dates, you can type '+' or '-' to increment or \
decrement the selected date. You can use '+' and '-' to increment and \
decrement check numbers as well.")

 N_( "To switch between multiple tabs in the main window, press \
Control+Page Up/Down.")

 N_( "In the reconcile window, you can press the spacebar to mark \
transactions as reconciled. You can also press Tab and Shift-Tab to \
move between deposits and withdrawals.")

 N_( "To transfer funds between accounts with different currencies, \
click on the Transfer button in the register toolbar, select the \
accounts, and the Currency Transfer options for entering the exchange \
rate or the other currency's amount will be available.")

 N_( "You can set the Security Editor screen to display the Quote Source \
of a security, which makes it easy to see which online sources your \
securities use. Click the triangle at the far right of the column \
headings to change the display.")

 N_( "You can pack multiple reports into a single window, \
providing all the financial information you want at a glance. \
To do so, use the Sample & Custom->\"Custom Multicolumn Report\" \
report.")

 N_( "Style Sheets affect how reports are displayed. Choose \
a style sheet for your report as a report option, and use \
the Edit->Style Sheets menu to customize style sheets.")

 N_( "To raise the accounts menu in the transfer field of a register \
page, press the Menu key or the Ctrl-Down key combination.")

 N_( "The scheduled transaction editor comes with a very flexible \
frequency configurator. Basic frequencies to schedule a transaction \
include daily, weekly and monthly. But more advanced schemes can be \
set up as well. Some examples:\n\nTo schedule a transaction every \
three weeks, you can choose the weekly basic frequency and then \
set 'Every 3 weeks'.\n\nTo schedule a transaction every year \
you can choose the monthly basic frequency and then set 'Every \
12 months'.")

 N_( "If you work overnight, you should close and reopen your working \
registers after midnight, to get the new date as default for new \
transactions. It is not necessary to restart GnuCash.")

 N_( "To search through all your transactions, start a search (Edit->\
Find…) from the main accounts hierarchy page. To limit your search \
to a single account, start the search from that account's register.")

 N_( "To visually compare on screen the contents of 2 tabs, \
in one of the tabs, select Window->New Window with Page \
from the menu to duplicate that tab in a new window.")

 N_( "There is a theory that if ever anyone discovers what \
the Universe is for and why it is here, it will instantly \
disappear and be replaced with something even more bizarre and \
inexplicable.\n\
There is another theory that this has already happened.\n\n\
Douglas Adams, \"The Restaurant at the End of the Universe\"")

/* Douglas Adams should be the last tip. Insert new tips in front of it. */

==> gnucash_5.5.orig.tar.xz: gnucash-5.5/doc/tip_of_the_day.list.c <==
/* Sort order: Imagine a first time user. When is your tip useful? */

 N_( "The GnuCash online manual has lots of helpful information. \
You can access the manual under the Help menu.")

/* Translators: You can replace the link, if a translated page exists. */
 N_( "Mailing lists are the preferred form of communication in the \
GnuCash community. For announcements of new releases, user groups etc. \
see the table at https://wiki.gnucash.org/wiki/Mailing_Lists")

 N_( "The GnuCash developers are easy to contact. As well \
as several mailing lists, you can chat to them live on IRC! \
Join them on #gnucash at irc.gnome.org")

 N_( "You can easily import your existing financial data from Quicken, \
MS Money or other programs that export QIF files or OFX files. In the \
File menu, click on the sub-menu Import and click on QIF or OFX file, \
respectively. Then, follow the instructions provided.")

 N_( "If you want to know in which directories your recent GnuCash files \
are stored, hover over one of the entries in the history menu\n(File[->\
Most Recently Used-List]).\nThe full path is displayed in the status bar.")

 N_( "If you are familiar with other financial programs such as Quicken, \
note that GnuCash uses accounts instead of categories to track \
income and expenses. For more information on income and expense \
accounts, please see the GnuCash online manual.")

 N_( "It is possible to change which columns display in the Chart of \
Accounts. Just locate the triangle at the far right of the column \
headings, and click it to see the different columns available.")

 N_( "Click the right mouse button (control-click in Mac OS X) in the \
Accounts tab of the main window to bring up the \
account menu options. Within each register, clicking the right \
mouse button brings up the transaction menu options.")

 N_( "Create new accounts by clicking the New button in the main window \
tool bar. This will bring up a dialog box where you can enter \
account details. For more information on choosing an account type \
or setting up a chart of accounts, please see the GnuCash online \
manual.")

N_( "Every transaction has a \"Notes\" field where you can put useful \
information.\n\n\
To make it visible\n\
select \"View\" in the menu bar and check \"Double Line\" or\n\
check \"Double Line View\" in Preferences:Register Defaults.")

 N_( "To enter multiple-split transactions such as a paycheck with \
multiple deductions, click the Split button in the tool bar. \
Alternatively, in the View menu, you can choose the register \
style Auto-Split Ledger or Transaction Journal.")

 N_( "As you enter amounts in the register, you can use the GnuCash \
calculator to add, subtract, multiply and divide. Simply type \
the first value, then select '+', '-','*', or '/'. Type the \
second value and press Enter to record the calculated amount.")

 N_( "Quick-fill makes it easy to enter common transactions. When you \
type the first letter(s) of a common transaction description, \
then press the Tab key, GnuCash will automatically complete \
the remainder of the transaction as it was last entered.")

 N_( "Type the first letter(s) of an existing account name in the \
Transfer register column, and GnuCash will complete the name from \
your list of accounts. For subaccounts, type the first letter(s) \
of the parent account, followed by ':' and the first letter(s) of \
the subaccount (e.g. A:C for Assets:Cash).")

 N_( "Want to see all your subaccount transactions in one register? \
From the Accounts tab in the main window, highlight the parent account \
and select Edit->Open Subaccounts from the menu.")

 N_( "When entering dates, you can type '+' or '-' to increment or \
decrement the selected date. You can use '+' and '-' to increment and \
decrement check numbers as well.")

 N_( "To switch between multiple tabs in the main window, press \
Control+Page Up/Down.")

 N_( "In the reconcile window, you can press the spacebar to mark \
transactions as reconciled. You can also press Tab and Shift-Tab to \
move between deposits and withdrawals.")

 N_( "To transfer funds between accounts with different currencies, \
click on the Transfer button in the register toolbar, select the \
accounts, and the Currency Transfer options for entering the exchange \
rate or the other currency's amount will be available.")

 N_( "You can set the Security Editor screen to display the Quote Source \
of a security, which makes it easy to see which online sources your \
securities use. Click the triangle at the far right of the column \
headings to change the display.")

 N_( "You can pack multiple reports into a single window, \
providing all the financial information you want at a glance. \
To do so, use the Sample & Custom->\"Custom Multicolumn Report\" \
report.")

 N_( "Style Sheets affect how reports are displayed. Choose \
a style sheet for your report as a report option, and use \
the Edit->Style Sheets menu to customize style sheets.")

 N_( "To raise the accounts menu in the transfer field of a register \
page, press the Menu key or the Ctrl-Down key combination.")

 N_( "The scheduled transaction editor comes with a very flexible \
frequency configurator. Basic frequencies to schedule a transaction \
include daily, weekly and monthly. But more advanced schemes can be \
set up as well. Some examples:\n\nTo schedule a transaction every \
three weeks, you can choose the weekly basic frequency and then \
set 'Every 3 weeks'.\n\nTo schedule a transaction every year \
you can choose the monthly basic frequency and then set 'Every \
12 months'.")

 N_( "If you work overnight, you should close and reopen your working \
registers after midnight, to get the new date as default for new \
transactions. It is not necessary to restart GnuCash.")

 N_( "To search through all your transactions, start a search (Edit->\
Find…) from the main accounts hierarchy page. To limit your search \
to a single account, start the search from that account's register.")

 N_( "To visually compare on screen the contents of 2 tabs, \
in one of the tabs, select Window->New Window with Page \
from the menu to duplicate that tab in a new window.")

 N_( "You can assign or modify keyboard shortcuts for many GnuCash \
actions. See https://wiki.gnucash.org/wiki/Keyboard_Shortcuts.")

 N_( "There is a theory that if ever anyone discovers what \
the Universe is for and why it is here, it will instantly \
disappear and be replaced with something even more bizarre and \
inexplicable.\n\
There is another theory that this has already happened.\n\n\
Douglas Adams, \"The Restaurant at the End of the Universe\"")

/* Douglas Adams should be the last tip. Insert new tips in front of it. */
